@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c 10781 2008-04-07 09:10:28Z vuntz $ */
+/* $Id: gweather-pref.c 11289 2009-02-16 23:48:56Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -24,7 +24,6 @@
 #include <ctype.h>
 #include <locale.h>
 
-#include <gnome.h>
 #include <panel-applet.h>
 #include <gconf/gconf-client.h>
 
@@ -341,16 +340,16 @@ auto_update_toggled (GtkToggleButton *button, GWeatherPref *pref)
     soft_set_sensitive (pref->priv->basic_update_spin, toggled);
     gweather_gconf_set_bool(gw_applet->gconf, "auto_update", toggled, NULL);
     if (gw_applet->timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->timeout_tag);
+        g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->suncalc_timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->suncalc_timeout_tag);
+        g_source_remove(gw_applet->suncalc_timeout_tag);
     if (gw_applet->gweather_pref.update_enabled) {
-        gw_applet->timeout_tag = gtk_timeout_add (
+        gw_applet->timeout_tag = g_timeout_add (
 				gw_applet->gweather_pref.update_interval * 1000,
 				timeout_cb, gw_applet);
 	nxtSunEvent = weather_info_next_sun_event(gw_applet->gweather_info);
 	if (nxtSunEvent >= 0)
-	    gw_applet->suncalc_timeout_tag = gtk_timeout_add (
+	    gw_applet->suncalc_timeout_tag = g_timeout_add (
 	    						nxtSunEvent * 1000,
 							suncalc_timeout_cb,
 							gw_applet);
@@ -546,10 +545,10 @@ update_interval_changed (GtkSpinButton *button, GWeatherPref *pref)
     gweather_gconf_set_int(gw_applet->gconf, "auto_update_interval", 
     		               gw_applet->gweather_pref.update_interval, NULL);
     if (gw_applet->timeout_tag > 0)
-        gtk_timeout_remove(gw_applet->timeout_tag);
+        g_source_remove(gw_applet->timeout_tag);
     if (gw_applet->gweather_pref.update_enabled)
         gw_applet->timeout_tag =  
-        	gtk_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
+        	g_timeout_add (gw_applet->gweather_pref.update_interval * 1000,
                                  timeout_cb, gw_applet);
 }
 
@@ -735,9 +734,9 @@ static void help_cb (GtkDialog *dialog)
 {
     GError *error = NULL;
 
-    gnome_help_display_on_screen (
-		"gweather", "gweather-settings",
-		gtk_window_get_screen (GTK_WINDOW (dialog)),
+    gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+		"ghelp:gweather?gweather-settings",
+		gtk_get_current_event_time (),
 		&error);
 
     if (error) { 
