@@ -29,7 +29,6 @@
 G_BEGIN_DECLS
 
 #include <gtk/gtkwidget.h>
-#include <gtk/gtktooltips.h>
 #include <panel-applet.h>
 
 typedef struct _MCData MCData;
@@ -39,16 +38,12 @@ typedef struct _MCData MCData;
 /* Constants */
 #define MC_NUM_LISTENERS                12
 #define MC_HISTORY_LIST_LENGTH          50
-#define MC_MAX_COMMAND_LENGTH           500
+#define MC_MAX_COMMAND_LENGTH           505
 #define MC_MAX_NUM_MACRO_PARAMETERS     100
 
 struct _MCData {
     PanelApplet   *applet;
 
-    GtkTooltips   *tooltips;
-
-    GtkWidget     *about_dialog;
-
     GtkWidget     *applet_box;
 
     GtkWidget     *entry;
